Releases
========

master
------

19.1.0
------

 * September 10, 2019
 * bump dependency versions
 * follow 301 and 302 when downloading Tor Browser


19.0.0
------

 * January 15, 2019
 * bump dependency versions
 * thanks to `rprimus <https://github.com/rprimus>`_ several cleanups:
 * remove `__future__` imports we don't need any longer
 * fix use of `await` as a variable name


18.4.0
------

 * `--detach` option for `carml onion`
 * `--json` option for `carml onion`


18.3.0
------

 * October 23, 2018
 * fix a few Python3 issues
 * OnionOO changed a few result tags
 * :ref:`onion` can accept + output private-keys
 * fix bug with `carml onion` not accepting single-port `--port` correctly


18.2.0
------

 * September 26, 2018
 * `carml` is now Python3-only
 * add :ref:`onion` sub-command to add Onion services to a Tor instance


18.1.0
------

 * June 26, 2018


18.0.0
------

 * April 16, 2018


17.4.0
------

 * May 15, 2017


17.3.0 and earlier
------------------

 * see `PyPI <https://pypi.org/project/carml/#history PyPI>`_


0.0.0 - 0.0.6
-------------

 * August 3, 2014
 * Initial release. Some issues with PyPI caused my to have to incrememnt the version several times.
